@@ -3,7 +3,8 @@
 
 #include <orbit/poa/poa-defs.h>
 #include <orbit/poa/poa-types.h>
-#include <orbit/poa/poa-policy.h>
+
+G_BEGIN_DECLS
 
 typedef struct {
   void *_private;
@@ -130,9 +131,11 @@ void ORBit_classinfo_register(PortableServer_ClassInfo *ci);
 
 #ifdef ORBIT2_INTERNAL_API
 
-PortableServer_ClassInfo *ORBit_classinfo_lookup(const char *type_id);
-void ORBit_POAObject_post_invoke(ORBit_POAObject obj);
+PortableServer_ClassInfo *ORBit_classinfo_lookup (const char *type_id);
+void ORBit_POAObject_post_invoke (ORBit_POAObject obj);
 
 #endif /* ORBIT2_INTERNAL_API */
 
+G_END_DECLS
+
 #endif
