@@ -571,6 +571,8 @@ ORBit_small_invoke_stub (CORBA_Object       obj,
 	adaptor_obj = obj->adaptor_obj;
 
 	if (adaptor_obj) {
+		tprintf_header (obj, m_data);
+		tprintf ("[in-proc]");
 		ORBit_small_handle_request (adaptor_obj, m_data->name, ret,
 					    args, ctx, NULL, ev);
 		goto clean_out;
@@ -715,7 +717,7 @@ ORBit_small_invoke_adaptor (ORBit_OAObject     adaptor_obj,
 				break;
 			case STRUCT_UNION_TYPES:
 			case CORBA_tk_array:
-				if (m_data->flags & ORBit_I_COMMON_FIXED_SIZE) {
+				if (a->flags & ORBit_I_COMMON_FIXED_SIZE) {
 					p = args [i] = alloca (ORBit_gather_alloc_info (tc));
 					do_demarshal_value (recv_buffer, &p, tc, orb);
 					p = args [i];
@@ -744,7 +746,7 @@ ORBit_small_invoke_adaptor (ORBit_OAObject     adaptor_obj,
 				break;
 			case STRUCT_UNION_TYPES:
 			case CORBA_tk_array:
-				if (m_data->flags & ORBit_I_COMMON_FIXED_SIZE) {
+				if (a->flags & ORBit_I_COMMON_FIXED_SIZE) {
 					scratch [i] = ORBit_alloc_by_tc (tc);
 					break;
 				} /* drop through */
@@ -930,7 +932,7 @@ ORBit_small_invoke_adaptor (ORBit_OAObject     adaptor_obj,
 				break;
 			case STRUCT_UNION_TYPES:
 			case CORBA_tk_array:
-				if (m_data->flags & ORBit_I_COMMON_FIXED_SIZE) {
+				if (a->flags & ORBit_I_COMMON_FIXED_SIZE) {
 					ORBit_freekids_via_TypeCode (tc, args [i]);
 					break;
 				}
@@ -1052,7 +1054,8 @@ async_recv_cb (ORBitAsyncQueueEntry *aqe)
 		CORBA_exception_set_system (ev, ex_CORBA_COMM_FAILURE,
 					    aqe->completion_status);
 
-	aqe->fn (aqe->obj, aqe->m_data, aqe, aqe->user_data, ev);
+	if (aqe->fn)
+		aqe->fn (aqe->obj, aqe->m_data, aqe, aqe->user_data, ev);
 
 	ORBit_RootObject_release (aqe->obj);
 /*	ORBit_RootObject_release (aqe->m_data); */
